#!/usr/bin/env python
#-*- coding:utf-8 -*-
__author__='whb'

def setcolor(color):
    def inner(msg,bold=False):
        color = '1;%d'%color if bold else str(color)
        return '\033[%sm%s\033[0m'%(color,msg)
    return inner


black = setcolor(30)
red = setcolor(31)
green = setcolor(32)
yellow = setcolor(33)
blue = setcolor(34)
cyanine = setcolor(36)
white = setcolor(37)




#!/usr/bin/env python
# -*- coding:utf-8 -*-


import random



def get_user_agent():
    user_agent_list = [
            'Mozilla/5.0 (X11; Linux i686) AppleWebKit/537.31 (KHTML, like Gecko) Chrome/26.0.1410.43 Safari/537.31',\

            'Mozilla/5.0 (Windows NT 6.1; WOW64) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1312.60 Safari/537.17',\
            'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_8_2) AppleWebKit/537.17 (KHTML, like Gecko) Chrome/24.0.1309.0 Safari/537.17',\
            \
            'Mozilla/4.0 (compatible; MSIE 8.0; Windows NT 6.2; Trident/4.0; SLCC2; .NET CLR 2.0.50727; .NET CLR 3.5.30729; .NET CLR 3.0.30729; Media Center PC 6.0)',\
            'Mozilla/5.0 (Windows; U; MSIE 7.0; Windows NT 6.0; en-US)',\
            'Mozilla/5.0 (Windows; U; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)',\
            \
            'Mozilla/6.0 (Windows NT 6.2; WOW64; rv:16.0.1) Gecko/20121011 Firefox/16.0.1',\
            'Mozilla/5.0 (X11; Ubuntu; Linux i686; rv:15.0) Gecko/20100101 Firefox/15.0.1',\
            'Mozilla/5.0 (Windows NT 6.2; WOW64; rv:15.0) Gecko/20120910144328 Firefox/15.0.2',\
            \
            'Mozilla/5.0 (Windows; U; Windows NT 6.1; rv:2.2) Gecko/20110201',\
            'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.9a3pre) Gecko/20070330',\
            'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10.6; en-US; rv:1.9.2.13; ) Gecko/20101203',\
            \
            'Opera/9.80 (Windows NT 6.0) Presto/2.12.388 Version/12.14',\
            'Opera/9.80 (X11; Linux x86_64; U; fr) Presto/2.9.168 Version/11.50',\
            'Opera/9.80 (Macintosh; Intel Mac OS X 10.6.8; U; de) Presto/2.9.168 Version/11.52',\
            \
            'Mozilla/5.0 (Windows; U; Win 9x 4.90; SG; rv:1.9.2.4) Gecko/20101104 Netscape/9.1.0285',\
            'Mozilla/5.0 (Macintosh; U; PPC Mac OS X Mach-O; en-US; rv:1.8.1.7pre) Gecko/20070815 Firefox/2.0.0.6 Navigator/9.0b3',\
            'Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.8.1.12) Gecko/20080219 Firefox/2.0.0.12 Navigator/9.0.0.6',\
        ]
    return random.choice(user_agent_list)



if __name__ == "__main__":

    user = get_user_agent()
    print user


# -*- coding: UTF-8 -*-
#!/usr/bin/env python
__author__ = 'whb'

import xlwt
import xlrd
from xlutils.copy import copy
import time
import shutil
import os,sys
import commands


class Excel(object):

    def __init__(self,filename):
        # get the full name of excel
        self.xlsname ='.'.join([filename,'xls'])


    def move(self,dest):
        shutil.move(self.xlsname,dest)

    def sync(self,dest):
        # compared to move method,it can modify the existence file
        os.system('rsync -av %s %s'%(self.xlsname,dest))

    def _connect_excel(self,read_only=True,create_new=None):
        '''
        if the target file dose not exist,then create file named self.xlsname
        :param create:
        :return:workbook
        '''
        try:
            return copy(xlrd.open_workbook(self.xlsname))
        except Exception,e:
            if create_new:
                print 'create new'
                obj = xlwt.Workbook(encoding='utf8')
                obj.add_sheet('sample')
                obj.save(self.xlsname)
                return copy(xlrd.open_workbook(self.xlsname))
            else:
                print create_new,'fuck'
                sys.exit(0)


class RExcel(Excel):

    def __init__(self,filename,data_struct):
        super(RExcel,self).__init__(filename)
        self.obj = self._connect_excel()
        self.data_struct = data_struct

    def get_sheet(self,sheetname = None,sheetid = None):
        if sheetname:
            sheet = self.obj.sheet_by_name(sheetname)
        elif sheetid:
            sheet = self.obj.sheet_by_index(sheetid)
        else:
            print 'pls input sheetname or sheeetid'
            sys.exit(0)
        return sheet

    #data_struct is according to the target excel file {'colname':colnumber}
    def read_one_sheet(self,sheetname=None,sheetid=None):
        self.sheet = self.get_sheet(sheetname,sheetid)
        for row in  range(1,self.sheet.nrows):
            element = {}
            for key in self.data_struct.keys():
                element[key] = self.sheet.cell(row,self.data_struct[key]).value
            yield element

    # read all data of all sheets in target file
    def read_all(self):
        for s in self.obj.sheets():
            for row in range(1,s.nrows):
                values = []
                for c in range(s.ncols):
                    values.append(s.cell(row,c).value)
                print ','.join(values)


class WExcel(Excel):

    def __init__(self,filename,data_struct):
        super(WExcel,self).__init__(filename)
        self.wobj = self._connect_excel(create_new=True)
        self.data_struct = data_struct

    def style(self,**fontargs):
        al = xlwt.Alignment()
        al.horz = xlwt.Alignment.HORZ_CENTER
        al.vert = xlwt.Alignment.VERT_CENTER
        style=xlwt.XFStyle()
        style.alignment=al
        font=xlwt.Font()
        font.name='SimSun'
        font.height=220
        if fontargs:
            for key in fontargs:
                if hasattr(font,key):
                    setattr(font,key,fontargs[key])
        style.font=font
        return self.style


    def _add_sheet(self,sheetname):
        for sh in sheetname:
            self.wobj.add_sheet(sh)
        #self.wobj.save(self.xlsname)


    def write_title(self,sheetid):
        sheet =self.wobj.get_sheet(sheetid)
        al = xlwt.Alignment()
        al.horz = xlwt.Alignment.HORZ_CENTER
        al.vert = xlwt.Alignment.VERT_CENTER
        style = xlwt.XFStyle()
        style.alignment = al
        font = xlwt.Font()
        font.name = 'SimSun'
        font.height = 330
        font.colour_index = 33
        borders = xlwt.Borders()
        borders.left = xlwt.Borders.THICK
        borders.right = xlwt.Borders.THICK
        borders.top = xlwt.Borders.THICK
        borders.bottom = xlwt.Borders.THICK
        style.borders = borders
        style.font = font
        for key in self.data_struct:
            col = int(self.data_struct[key])
            sheet.write(0,col,key,style)

    def write(self,sheetid,data,row):
        sheet = self.wobj.get_sheet(sheetid)
        if isinstance(data,dict):
            for key in item.keys():
                sheet.write(row,int(self.data_struct[key]),item[key])
                row += 1
        elif isinstance(data,tuple and list):
            data = [item for item in data if item]
            for item in data:
                for key in item.keys():
                    print key
                    sheet.write(row,int(self.data_struct[key]),item[key])
                row += 1
        else:
            return

    def save(self):
       self.wobj.save(self.xlsname)


def test():
    data_struct = {u'姓名':0,u'年龄':1}
    #e =Excel('test')
    q = WExcel('tess',data_struct)
    q._add_sheet(['ss','sg'])
    #q.write(data_struct)
    q.write_title(2)
    q.write(1,[{u'年龄':25,u'姓名':u'海波'}],1)
    q.save()
    q.move('e:\\find_job')




if __name__=="__main__":
    test()
    print os.path.abspath('test.xls')







#!/usr/bin/env python
# -*- coding:utf-8 -*-



"""
store_data.py

the data needed sotred is in format:[{},{},{}],we can store them in Mysql ,json or Redis

"""

#from baseclass.database import Database
import json
import os
from datetime import datetime,date
from  ..database import Database

class Job_Data():

    def __init__(self,store_type='json'):
        self.store_type = store_type
        self.today = date.today().strftime("%Y-%m-%d")


    def store(self,data):
        if self.store_type == 'MySQL':
            self.store_to_mysql(data)
        elif self.store_type == 'json':
            self.store_to_json(data)
        elif self.store_type == 'excel':
            self.store_to_excel(data)
        elif self.store_type == 'redis':
            self.store_to_redis(data)

    def store_to_mysql(self,data):
        self.db = Database('Job')
        for item in data:
            item['create_day'] = self.today
        self.db.insert_dic_by_list('jobs',data)

    def store_to_json(self,data,filename='-'.join([date.today().strftime("%Y-%m-%d"),'job.json'])):
        basepath = '/'.join(os.path.abspath(os.path.dirname(__file__)).split('/')[:-1])
        if os.name == 'nt':
            filepath = os.path.join(basepath,'%s'%filename)
            print 'json file is stored in C:\python'
        else:
            filepath = os.path.join('/tmp',filename)
            print 'json file is stored in %s ' % filepath
        for item in data:
            #print item['title'],item['link']
            json_data = json.dumps(item)
            with file(filepath,'w') as json_file:
                json_file.write(json_data)
                json_file.write('\n')

    def store_to_excel(self,data,filename='job.xlsx'):
        pass

    def store_to_redis(self,data,keyname='job'):
        pass

    




#!/usr/bin/env python
# -*- coding: utf-8 -*-


import sys
import redis
import cPickle as P



class MyRedis():

    config={
             'local':{
                    'host':'127.0.0.1',
                    'port':6379,
                    'db':0,
                    'password':'*******'
                    },
             'virtual':{
                    'host':'192.168.6.128',
                    'port':6379,
                    'db':0,
                    'password':'*******'
                    },
            }


    def __init__(self,host):
        self.host = host
        self.__connect()


    def __connect(self):
        'any command can be executed by using self.redis'
        self.conn = redis.Connection(host=self.config[self.host]['host'],
                                     port=self.config[self.host]['port'],
                                     db=self.config[self.host]['db'],
                                     password=self.config[self.host]['password'])

        self.rs = redis.Redis(host=self.config[self.host]['host'],
                              port=self.config[self.host]['port'],
                              db=self.config[self.host]['db'],
                              password=self.config[self.host]['password'])


    # any command used in redis client can be regarded as a string to be executed
    def query(self,cmd):
        self.conn.send_command(cmd)
        return self.conn.read_response()

    def pipe_exec(self,**kargs):
        pipe=self.rs.pipeline()
        for key in kargs:
            if hasattr(self.rs,key):
                apply(getattr(self.rs,key),kargs[key])
        pipe.execute()


    def set(self,name,data):
        #set one hash table which contains several fields
        ''' for tuple or list:
        1.first serialization of data to string,
        2.then store it in string format'''
        if isinstance(data,(basestring,bytes)):
            self.rs.set(name,data)
        elif isinstance(data,list or tuple):
            data=P.dumps(data)
            self.rs.set(name,data)
        elif isinstance(data,dict):
            if self.rs.hmset(name,data):
                print 'store OK'
            else:
                print 'set fail'
        else:
            print 'incorrect data type'
            return None

    def dictget(self,name,select='all'):
        ''' First by cmd "hgetall" get dict,if error occurs,
        that means it is serialized by pickle,need by get'''
        try:
            if select=='all':
                return self.rs.hgetall(name)
            elif isinstance(select,list or tuple):
                return self.rs.hmget(name,select)
        except:
            result=self.rs.get(name)
            if not result:
                return None
            try:
                return P.loads(result)
            except:
                sys.exit()






def test():

    myredis=MyRedis('local')
    print myredis.rs.type('love')
    print myredis.query('lrange love 0 -1')




if __name__=="__main__":

    test()



#!/usr/bin/python
# -*- coding: utf-8 -*-
__author__ = 'WHB'



from baseclass.base_spider import Base_Spider



class ZL_Spider(Base_Spider):
    '''
    the website is qianchengwuyou,it is like lagou,
    no need ajax
    '''
    def __init__(self,website,*args):
        #no need any key except User-Agent
        super(ZL_Spider,self).__init__(website,args)

    def parse(self,url):
        soup = self.get_content(url)
        result = []
        tables = soup.find(id="newlist_list_content_table")
        if tables is not None:
            for table in list(tables.children):
                if table.name is None:
                    continue
                else:
                    item = {}
                    item['website'] = 'zhilian'
                    #print 'test',type(table),table.name
                    Trinfo = table.find('tr')
                    title = Trinfo.find('td','zwmc')
                    if title is not None:
                        item['link'] = title.find('a')['href']
                        item['title'] = title.find('a').text
                    Comp = Trinfo.find('td','gsmc')
                    if Comp is None:
                        continue
                    else:
                        item['homepage'] = Comp.find('a')['href']
                        item['company'] = Comp.find('a').text
                    intro = Trinfo.find('td','gzdd')
                    #item[u'介绍'] = intro.text if intro is not None else ''
                    date = Trinfo.find('td','gxsj')
                    item['date'] = date.text if date is not None else ''
                  #  for key in item:
                     #   print key,item[key]
                    result.append(item)
        return [item for item in result if item]

    def pages_parse(self,keyword):
        for page in xrange(1,2):
            url = 'http://sou.zhaopin.com/jobs/searchresult.ashx?jl=&kw=%s&sm=0&sg=654c99887ed049479fb08d6530323db0&p=%d&isfilter=0&fl=530&isadv=0&sb=1'%(keyword,page)
            data = self.parse(url)
            yield data






#!/usr/bin/env python
# -*- coding: utf-8 -*-

import urllib
import urllib2
import requests
import json
import re
import os
import ConfigParser 
from bs4 import BeautifulSoup
from cStringIO import StringIO
import cookielib
import xml.etree.ElementTree as ET
from .utils.get_user_agent import get_user_agent
from .config import ByrCfg,Job51Cfg,ZhiCfg,LgCfg,DjCfg

class Base_Spider(object):

    def __init__(self,sitename,*args):
        """
        it's the name of the website that you'll visit,
        it's used to get config info from config file
        """
        self.sitename = sitename
        self.setHeaders(*args)


    def setHeaders(self,*args):
        '''
        add header in order to model explorer,including:
        User-Agent,Referer,Host
        :return:None
        '''
        self.headers = {}
        self.headers.setdefault('User-Agent',get_user_agent())
        for key in args[0]:
            self.get_cfg(self.headers,key)


    def get_cfg(self,field,key):
        SiteCfg = {'byr':ByrCfg(),'lagou':LgCfg(),'zhilian':ZhiCfg(),'51job':Job51Cfg(),'dajie':DjCfg()}
        self.cfg = SiteCfg[self.sitename]
        if key == 'X-Requested-With':
            field[key] = getattr(self.cfg,'X_Requested_With')
        else:
            field[key] = getattr(self.cfg,key)


    def build_opener(self,save = False):
        if not save:
            cj = cookielib.LWPCookieJar()
            opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj),
                                          urllib2.HTTPHandler)
        else:
            cj =cookielib.MozillaCookieJar()
            cj.save('cookie.txt',ignore_discard=True,ignore_expires=True)
            opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
        urllib2.install_opener(opener)
        return opener
        #download cookie in order to post data for logining
        #h = urllib2.urlopen(self.host_url)


    def login(self,posturl,postdata):
        '''
        self.build_opener()
        postdata = urllib.urlencode(postdata)
        request = urllib2.Request(url=posturl,data=postdata,headers=self.headers)
        #print self.opener.open(request)
        resp = urllib2.urlopen(request).read()
        print resp
        '''
        self.session = requests.Session()
        r = self.session.post(posturl,data=postdata)
        return dict(r.cookies) if not isinstance(r.cookies,dict) else r.cookies


    # get content which is in three different data format
    def get_content(self,url,url_type='html',cookies=None):
        if 'X-Requested-With' not in self.headers.keys():
            #content = urllib2.urlopen(url)
            content = requests.get(url,headers=self.headers)
            try:
                #get original data brfore transferring unicode
                content = content.content
            except UnicodeEncodeError:
                content = content.text.encode('utf-8')
            except UnicodeDecodeError:
                print 'test'
                content = content.text
        else:
            opener = self.build_opener()
            header_list = []
            for key in self.headers.keys():
                header_list.append((key,self.headers[key]))
            opener.addheaders = header_list
            content = opener.open(url).read()
            try:
                if not isinstance(content,basestring and unicode):
                        content = content.decode('GBK').encode('utf8')
            except UnicodeDecodeError:
                pass
        content = StringIO(content)
        #print content.read(),'test cstr'
        if url_type == 'json':
            return json.load(content)
        elif url_type == 'xml':
            return ET.parse(content)
        else:
            return BeautifulSoup(content,"html5lib")

    def login_get_content(self,url,url_type='html',cookies=None):
        content = self.session.get(url,timeout = 15) if cookies is None \
            else self.session.get(url,cookies=cookies)
        try:
            #get original data brfore transferring unicode
            content = content.content
        except UnicodeEncodeError:
            content = content.text.encode('utf-8')
        except UnicodeDecodeError:
            print 'test'
            content = content.text
        content = StringIO(content)
        #print content.read(),'test cstr'
        if url_type == 'json':
            return json.load(content)
        elif url_type == 'xml':
            return ET.parse(content)
        else:
            return BeautifulSoup(content,"html5lib")

    def store(self):
        pass

    def upload_file(self,url,filename):
        with file(filename,'rb') as f:
            requests.post(url,data=f)

    def download(self,imgurl,filename):
        resp = requests.get(imgurl)
        with file(filename,'wb') as f:
            f.write(resp.content)


if __name__ == "__main__":
    spider = Base_Spider('lagou',['Host',])
    print spider.headers


#!/usr/bin/env python
# -*- coding:utf-8 -*-

import urllib2
from baseclass.base_spider import Base_Spider




class BYR_Spider(Base_Spider):

    def __init__(self,website,*args):
        super(BYR_Spider,self).__init__(website,args)


    def parse(self,url):
        try:
            soup = self.get_content(url)
        except urllib2.URLError:
            soup = self.get_content(url)
        table = soup.find('table')
        title = {'title_9':'title','title_10':'date'}
        data = []
        for tr in table.find_all('tr')[1:]:
            item = {}
            for td in tr.find_all('td')[0:-2]:
                if td['class'][0] in title.keys():
                    if td['class'][0] == 'title_9':
                        item['link'] = 'http://bbs.byr.cn'+td.a['href']
                    item[title[td['class'][0]]] = td.get_text()
                item['website'] = 'byr'
                data.append(item)
        return [item for item in data if item]

    def pages_parse(self,keyword):
        for page in xrange(1,2):
            url = 'http://bbs.byr.cn/s/article?t1=%s&au=&b=JobInfo&_uid=guest&p=%d'%(keyword,page)
            data = self.parse(url)
            yield data



















#!/usr/bin/python

"""
Level	    Numeric value
CRITICAL	50
ERROR	    40
WARNING 	30
INFO	    20
DEBUG	    10
NOTSET	    0

"""





import logging
import os



class MyLogger():

    def __init__(self, name):
        self.logger = logging.getLogger(name)
        self._set_handlers()

    def _set_handlers(self):
        self.logger.addHandler(self.sta_handler)
        self.logger.addHandler(self.file_handler)

    @property
    def sta_handler(self):
        formater = logging.Formatter(
            '%(asctime)s %(levelname)s %(message)s in %(filename)s %(levelno)s'
        )
        com_handler = logging.StreamHandler()
        com_handler.setLevel(logging.ERROR)
        com_handler.setFormatter(formater)
        return com_handler

    @property
    def file_handler(self):
        formater = logging.Formatter(
            '%(asctime)s %(levelname)s %(message)s in %(filename)s %(levelno)s'
        )
        com_handler = logging.FileHandler('s.log')
        com_handler.setLevel(logging.ERROR)
        com_handler.setFormatter(formater)
        return com_handler



if __name__ == "__main__":
    l = MyLogger('haibo').logger
    l.error('test error')
    l.warn('test warn')

    sl = logging.getLogger('haibo.c')
    sl.warn('test inherit')




#!/usr/bin/python
# -*-coding:utf-8 -*-
import MySQLdb
from .utils.joblog import MyLogger

class Database():
    
    config={

                   'Job': {
                        'host': 'localhost',
                        'user': 'admin',
                        'passwd': 'admin',
                        'db': 'Job',
                        'charset': 'utf8'},
                  'local':{
                        'host':'127.0.0.1',
                        'user':'root',
                        'db':'***',
                        'passwd':'********',
                        'charset':'utf8'}
                 }
    
    def __init__(self,dbname):
        self._connect(dbname)
    
    def _connect(self,dbname):
        tar = self.config[dbname]
        self.con = MySQLdb.connect(tar['host'],tar['user'],tar['passwd'],tar['db'],charset=tar['charset'])
        self.cursor = self.con.cursor(cursorclass=MySQLdb.cursors.DictCursor)
        self.cursor.execute('SET NAMES utf8')
    
    def query_dic(self,sql,where=None,select=None):
        if where:
            sql = "%s where %s" % (sql,where)
        if select:
            sql = "%s %s" % (sql,select)
        #print sql
        self.cursor.execute(sql)
        return self.cursor.fetchall()
     
    
    def sql_exec(self, sql):
        self.cursor.execute(sql)
        self.conn.commit()

        
    def create_table(self,tablename,columns):
        sql = 'create table `%s`(%s)'%(tablename,columns)
        self.sql_exec(sql)
        
    def insert_by_dic(self,table,data):
        keys=data.keys()
        values=[]
        keystr = ','.join('`' + x + '`' for x in keys)
        for key in keys:
            values.append(data[key])
        valstr = ','.join( "'" + x + "'" if isinstance(x,unicode) \
                           else "'" + str(x).decode('utf8') +"'" for x in values )   
        sql="INSERT INTO  %s (%s) VALUES (%s) " % (table,keystr,valstr)
        self.cursor.execute(sql)
        self.con.commit()
    
        
    def insert_dic_by_list(self, table, tar_data):
        for data in tar_data:
            try:
                self.insert_by_dic(table, data)        
            except Exception,e:
                logger = MyLogger('jobspider').logger
                logger.error(str(e))
                continue
                
    def update_(self,table,key,value,ref_key,ref_value):
        sql = 'update %s set %s="%s" where %s="%s"'\
              %(table,key,value,ref_key,ref_value)
        #print sql
        self.sql_exec(sql)
        
    def update_by_dic(self,table,ref_key,ref_value,data):
        keys = data.keys()
        values=[]
        keystr = ['`' + x + '`' for x in keys]
        for key in keys:
            values.append(data[key])
        valstr = [ "'" + x + "'" if isinstance(x,unicode) \
                           else "'" + str(x).decode('utf8') +"'" for x in values]
        obj = ','.join(str(keystr[index])+"=%s"%valstr[index] \
                       for index in range(0,len(keys)))
        sql = 'UPDATE %s set %s where %s="%s"'%(table,obj,ref_key,ref_value)
        self.cursor.execute(sql)
        self.con.commit()


    def update_list_dic(self,table,ref_key,data):
        for d in data:
            try:
                ref_value=str(d[ref_key])
                self.update_by_dic(table,ref_key,ref_value,d)
            except Exception,e:
                print str(e),d
                continue

    def load_file_to_db(self, table, file_name):
        sql_load = "LOAD DATA LOCAL INFILE '%s' INTO TABLE %s \
                FIELDS TERMINATED BY ',' \
                ENCLOSED BY '' LINES TERMINATED BY '\n' " % ( 
            file_name, table)
        self.cursor.execute(sql_load)
        self.conn.commit()







#!/usr/bin/env python
# -*- coding:utf-8 -*-


from baseclass.base_spider import Base_Spider
from baseclass.utils.get_cookies import get_cookie

class DJ_Spider(Base_Spider):

    def __init__(self,website,*args):
        super(DJ_Spider,self).__init__(website,args)

    def parse(self,url):
        """
        :param url:
        :return:json data
        to get data from the data url,we must firstlt get response cookie,so
        we must get cookie from url:http://so.dajie.com/job/search?keyword=python&f=nav
        then we can get data normally
        """
        try:
            json_str = self.get_content(url,url_type='json')
        except ValueError:
            Cookie = get_cookie('http://so.dajie.com/job/search?keyword=python&f=nav')
            combin_cookie = ['='.join([key,value]) for key,value in Cookie]
            self.headers['Cookie'] = ';'.join(combin_cookie)
            json_str = self.get_content(url,url_type='json')
        metadata = json_str['data']['list']
        data=[]
        for md in metadata:
            item = {}
            try:
                item['website'] = 'dajie'
                item['link'] = md['liHref']
                item['title'] = md['jobName']
                item['company'] = md['compName']
                item['date'] = md['time']
                #item['intro'] = ':'.join([u'月薪',md['salary']])
                item['homepage'] = md['compHref']
            except KeyError,e:
                print str(e)
            data.append(item)
        return [item for item in data if item]

    def pages_parse(self,keyword):
        for page in xrange(1,2):
            url = 'http://so.dajie.com/job/ajax/search/filter?jobsearch=0&pagereferer=blank&ajax=1&keyword=%s&page=%d'%(keyword,page)+'&order=0&from=user&salary=&recruitType=3%2C4&city=110000&positionIndustry=&positionFunction=&degree=&quality=&experience=&internshipDays=&partTimeCategory=&_CSRFToken='
            #print url
            data = self.parse(url)
            yield data





if __name__=="__main__":

    dj = DJ_Spider('dajie','X-Requested-With','Host','Referer','Cookie')
    for item in dj.pages_parse('python'):
        print item









#!/usr/bin/env python
# -*- coding:utf-8 -*-

"""
run spider in two different ways

it can run in single spider ,selected from BYR,Lagou,Zhilian,51Job or
run in multiprocessing


Default,the data that spider crawls will be stored into json file ,of course,you can
store into MySQL,excel or redis by setting store type.

"""

import os
from multiprocessing import Pool,Manager

from byr import BYR_Spider
from lagou import LG_Spider
from zhilian import ZL_Spider
from job51 import Job51_Spider
from dajie import DJ_Spider

from baseclass.utils.store_data import Job_Data
from baseclass.utils.setcolor import *


class Spider():

    spiders = {
        'byr':BYR_Spider('byr','X-Requested-With','Host','Referer'),
        'lagou':LG_Spider('lagou'),
        'zhilian':ZL_Spider('zhilian'),
        '51job':Job51_Spider('51job','Host','Cookie'),
         'dajie':DJ_Spider('dajie','X-Requested-With','Host','Referer','Cookie')
               }

    def __init__(self,keyword,store_type='json'):
        self.keyword = keyword
        self.store_type = store_type

    def get_single_data(self,spiname):
        self.spider = self.spiders[spiname]
        data = self.spider.pages_parse(self.keyword)
        return data

    def single_run(self,spiname):
        db = Job_Data(self.store_type)
        for data in self.get_single_data(spiname):
			db.store(data)

    def single_print(self,spiname):
        for data in self.get_single_data(spiname):
            for item in data:
                for key,value in item.items():
                    print "%s : %s" %(key,value),
                print '\n'

    def multi_run(self,spiname):
        print spiname
        self.single_run(spiname)

    def print_output(self,spiname):
        #In Linux,it will print data with colored
        for data in self.get_single_data(spiname):
            for item in data:
                for key,value in item.items():
                    if not isinstance(key,unicode):
                        key = key.encode('utf8')
                    if not isinstance(value,unicode):
                        value = value.encode('utf8')
                    if os.name == 'posix':
                        try:
                            print '{0}:{1}'.format(red(key),value),
                        except UnicodeEncodeError :
                            key,value = key.encode('utf8'),value.encode('utf8')
                            print '{0}:{1}'.format(key,value)
                        else:
                            print '{0}:{1}'.format(key,value),
                    else:
                        try:
                            print '{0}:{1}'.format(key,value),
                        except UnicodeEncodeError :
                            key,value = key.encode('utf8'),value.encode('utf8')
                            print '{0}:{1}'.format(key,value)
                print '\n'

    def get_data(self,spiname):
        select = raw_input('you want put data into terminal or json(write ter or json):')
        if select == 'terminal':
            self.print_output(spiname)
        elif select == 'json':
            self.single_run(spiname)
        else:
            print 'your input is incorrect,it must be terminal or json'



def crawl(spi,lock,store_type):
    #get the spider object,when storing data,it will
    spider = Spider('python',store_type)
    #when storing data to json or database,should set lock in order to protecting the data
    lock.acquire()
    try:
        spider.multi_run(spi)
    finally:
        #the subprocess must release the resource whatever it has finished successfully or not.
        lock.release()


def producer(store_type='json'):
    """
    In this spider,we can use multiprocessing to crawl job data from
    several different website.
    It can save a lot time by using multiprocessing.and this usage is
    very simple,efficient and pythonic.
    :param:store_type, the format you store the data ,it can be MySQL,json file,excel and redis.

    """
    lock = Manager().Lock()
    p = Pool()
    sites = ['zhilian', '51job','byr','lagou','dajie']
    for site in sites:
        p.apply_async(crawl,args=(site,lock,store_type))
    p.close()
    p.join()


if __name__=="__main__":
	spider = Spider('python')
	spider.single_run("lagou")
	#producer(store_type='MySQL')








#!/usr/bin/env python
#encoding:utf8
'''
Author: whb
e-mail:hbnnlong@163.com
Date:2014-04-21
'''

import email
import time
from email.MIMEText import MIMEText
from email.MIMEMultipart import MIMEMultipart
from email.MIMEBase import MIMEBase
import smtplib
import os
import sys
import ConfigParser
import ast
import commands


class SendMail():

    def __init__(self,mail_type,user):
        self.mail_type = mail_type
        self._send_server = 'smtp.163.com'
        PackagePath = commands.getoutput('echo $PackagePath')
        self._cfg_path = '/'.join([PackagePath,'config/sendemail.cfg'])
        self._smtp = smtplib.SMTP(self._send_server)
        self.set_config()
        self.user = user

    def set_config(self):
        self.cfg = ConfigParser.ConfigParser()
        self.cfg.read(self._cfg_path)
        self.to_addrs =ast.literal_eval(self.cfg.get(self.mail_type,'addrs'))
        self.subject = self.cfg.get(self.mail_type,'subject')
        self.txt = self.cfg.get(self.mail_type,'txt')

    def send_email(self,filename=None,msghtml=None,msgtxt=None):
        ms = MIMEMultipart()
        Addrs = [email.utils.formataddr((False,addr)) for addr in self.to_addrs]
        print Addrs
        ms['To'] = ','.join(Addrs)
        ms['From'] = self.user
        ms['Subject'] = self.subject
        ms['Date'] = email.utils.formatdate(time.time(),True)
        #ms.attach(MIMEText(self.txt))
        if msghtml:
            ms.attach(MIMEText(msghtml,'html','utf8'))
   
        if filename:
            attat = MIMEText(file(filename,'rb').read(),'base64','utf8')
            attat["Content-Type"]='application/octet-stream'
            attat['Content-Disposition']='attatcnment;filename="%s" '%filename
            ms.attach(attat)
        
        if msgtxt:
            ms.attach(MIMEText(msgtxt,'plain','utf8'))    
        self._smtp.login(ms['From'],'*******')
        try:
            self._smtp.sendmail(ms['From'],Addrs,ms.as_string())
            self._smtp.quit()
            return
        except Exception,e:
            print str(e)


def test():
    S_mail = SendMail('test','email')
    S_mail.send_email('send_email.py',None,'hello,python')



if __name__=="__main__":

    test()




"""
jobspider
-----

jobspider can crawl several websites,we can get any data using some keyword

Jobspider is Useful
````````````

Save in a hello.py:

.. code:: python

    from jobpiser import Spider


    if __name__ == "__main__":
         spider = Spider('python')
         spider.single_run('lagou')

And Easy to Setup
`````````````````

And run it:

.. code:: bash

    $ pip install jobspider
    $ python hello.py


Links
`````
* `development version
  <https://github.com/haipersist/jobspider>`_

"""

from setuptools import setup



setup(
    name='jobspider',
    version='2.3.3',
    url='https://github.com/haipersist/jobspider',
    license='BSD',
    author='Haibo Wang',
    author_email='393993705@qq.com',
    description='A spider that crawls the job infos of famous website ',
    long_description=__doc__,
    packages=['jobspider','jobspider.baseclass','jobspider.baseclass.utils'],
    package_data={'jobspider': ['*.cfg']},
    package_dir={'jobspider': 'jobspider'},
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=[
        'requests>=2.8.1',
        'beautifulsoup4>=4.4.1',
        'xlutils>=1.7.1',
        'xlrd>=0.9.4',
        'xlwt>=1.0.0',
        'html5lib',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
    #entry_points='''
     #   [console_scripts]
      #  jobspider=jobspider.spider:main
    #'''
)



#!/usr/bin/python
# -*- coding:utf-8 -*-


from baseclass.base_spider import Base_Spider
from baseclass.utils.setcolor import *


class Job51_Spider(Base_Spider):
    '''
    the website is qianchengwuyou,it is like lagou,
    no need ajax
    '''
    def __init__(self,website,*args):
        super(Job51_Spider,self).__init__(website,args)


    def parse(self,url):
        headers = {
            'Host': 'www.search.51job.com',
            'User-Agent': 'Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:42.0) Gecko/20100101 Firefox/42.0',
            'Cookie': 'guid=14465584429375700076; slife=compfans%3D1%257C0%257C0%257C0; search=jobarea%7E%60010000%7C%21ord_field%7E%600%7C%21list_type%7E%600%7C%21recentSearch0%7E%602%A1%FB%A1%FA010000%2C00%A1%FB%A1%FA000000%A1%FB%A1%FA0000%A1%FB%A1%FA00%A1%FB%A1%FA9%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA01%A1%FB%A1%FA99%A1%FB%A1%FApython%A1%FB%A1%FA0%A1%FB%A1%FA%A1%FB%A1%FA-1%A1%FB%A1%FA1452781332%A1%FB%A1%FA0%A1%FB%A1%FA%7C%21recentSearch1%7E%602%A1%FB%A1%FA010000%2C00%A1%FB%A1%FA000000%A1%FB%A1%FA0000%A1%FB%A1%FA00%A1%FB%A1%FA9%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA01%A1%FB%A1%FA99%A1%FB%A1%FAAnroid%A1%FB%A1%FA2%A1%FB%A1%FA%A1%FB%A1%FA-1%A1%FB%A1%FA1452781220%A1%FB%A1%FA0%A1%FB%A1%FA%7C%21recentSearch2%7E%602%A1%FB%A1%FA010000%2C00%A1%FB%A1%FA000000%A1%FB%A1%FA0000%A1%FB%A1%FA00%A1%FB%A1%FA9%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA01%A1%FB%A1%FA99%A1%FB%A1%FApython%A1%FB%A1%FA2%A1%FB%A1%FA%A1%FB%A1%FA-1%A1%FB%A1%FA1452780011%A1%FB%A1%FA0%A1%FB%A1%FA%7C%21recentSearch3%7E%602%A1%FB%A1%FA010000%2C00%A1%FB%A1%FA000000%A1%FB%A1%FA0000%A1%FB%A1%FA00%A1%FB%A1%FA9%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FAAnroid%A1%FB%A1%FA2%A1%FB%A1%FA%A1%FB%A1%FA-1%A1%FB%A1%FA1452781294%A1%FB%A1%FA0%A1%FB%A1%FA%7C%21recentSearch4%7E%602%A1%FB%A1%FA010000%2C00%A1%FB%A1%FA000000%A1%FB%A1%FA0000%A1%FB%A1%FA00%A1%FB%A1%FA9%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FA99%A1%FB%A1%FApython%A1%FB%A1%FA0%A1%FB%A1%FA%A1%FB%A1%FA-1%A1%FB%A1%FA1452781317%A1%FB%A1%FA0%A1%FB%A1%FA%7C%21; guide=1; collapse_expansion=1; nolife=fromdomain%3D; ps=us%3DCzFUPVIyBi5RMQ1jBmtWewc1CzlVZVYtBjFUPwg3BXlbYlM8B2BXYwBmWz9XM1ZmV2RWYwQ0BWQANwUrXDAHVAtmVDhSVA%253D%253D; 51job=cenglish%3D0',
        }
        soup = self.get_content(url)
        #print soup
        try:
            resultlist = soup.find(id="resultList").find_all("div",class_='el')[1:]
        except AttributeError:
            print red('cookie may be invalid,pls check the cookie of webinfo.cfg')
        #print resultlist
        data = []
        for el in resultlist:
            item = {}
            #print el
            item['website'] = '51job'
            item['title']=el.find('p','t1').find('a').text
            item['link'] = el.find('p','t1').find('a')['href']
            item['company'] = el.find('span','t2').find('a').text
            item['homepage'] = el.find('span','t2').find('a')['href']
            item['salary'] = el.find('span','t4').text
            item['date'] = el.find('span','t5').text
            data.append(item)
        return data

    def pages_parse(self,keyword):
        for page in xrange(1,2):
            url = 'http://search.51job.com/jobsearch/search_result.php?fromJs=1&jobarea=010000%2C00&district=000000&funtype=0000&industrytype=00&issuedate=9&providesalary=99&' + \
                  'keyword=%s&keywordtype=0&curr_page=%d&lang=c&stype=2'%(keyword,page) + \
                  '&postchannel=0000&workyear=99&cotype=99&degreefrom=99&jobterm=01&companysize=99&lonlat=0%2C0&radius=-1&ord_field=0&list_type=0&fromType=14&dibiaoid=0'
            data = self.parse(url)
            yield data








#!/usr/bin/python
# -*- coding:utf-8 -*-


from baseclass.base_spider import Base_Spider




class LG_Spider(Base_Spider):

    def __init__(self,sitename,*args):
        #do not add host
        super(LG_Spider,self).__init__(sitename,args)
	

    def parse(self,url):
        response = self.get_content(url,url_type='json')
        content = response['content']
        if hasattr(self,'total_pages'):
            self.total_pages = content["totalPageCount"]
        data_list = content['result']
        result = []
        for data in data_list:
            item = {}
            item['website'] = 'lagou'
            item['link'] = 'http://www.lagou.com/jobs/'+str(data['positionId'])+'.html'
            item['homepage'] =  'http://www.lagou.com/gongsi/'+str(data['companyId'])+'.html'
            item['title'] = data['positionName']
            item['company'] = data['companyName']
            item['salary'] = data['salary']
            item['date'] = data['createTime']
            result.append(item)
        return result



		

    def pages_parse(self,keyword):
        for page in xrange(1,2):
            if not isinstance(keyword,unicode):
                keyword = keyword.encode('utf8')
            url = 'http://www.lagou.com/jobs/positionAjax.json?px=new&gx=%E5%85%A8%E8%81%8C&city=%E5%8C%97%E4%BA%AC&first=true&'+'kd=%s&pn=%d'%(keyword,page)
            data = self.parse(url)
            yield data




if __name__ == "__main__":
    lg = LG_Spider('lagou')
    for item in lg.pages_parse('python'):
        print item


